@@ -109,36 +109,13 @@ class MultiplesExperimentos:
             lista_arreglos_solo_regiones_no_preferidas.append(
                 experimento.matriz_cuadriculada_solo_regiones_no_preferidas.flatten())
         self.calcula_divergencia("visitas_regiones", lista_arreglos_regiones)
-        self.calcula_divergencia("visitas_regiones_preferenciales", lista_arreglos_solo_regiones_preferidas)
+        self.calcula_divergencia("visitas_regiones_preferidas", lista_arreglos_solo_regiones_preferidas)
         self.calcula_divergencia("visitas_regiones_no_preferidas", lista_arreglos_solo_regiones_no_preferidas)
 
     def calcula_divergencia(self, tipo_divergencia, lista_datos):
         lista_divergencia = ed.calcula_divergencias_de_lista_arreglos(lista_datos)
         self.resultados_divergencia[tipo_divergencia] = lista_divergencia
 
-    def graficar(self, grafica):
-        print("-----------------------------------------------")
-        print("Gráfica deseada", grafica)
-
-        cantidad_experimentos = len(self.lista_experimentos)
-
-        if grafica is 'entropia_visitas_regiones':
-            plt.plot(range(1, cantidad_experimentos+1),
-                     self.resultados_entropia["visitas_regiones"])
-            plt.show()
-
-        elif grafica is 'entropia_visitas_regiones_preferidasvelocidad':
-            plt.plot(range(1, cantidad_experimentos+1),
-                     self.resultados_entropia["visitas_regiones_preferidas"])
-            plt.show()
-
-        elif grafica is 'divergencia_regiones':
-            plt.plot(range(1, len(self.resultados_divergencia_regiones)+1),
-                     self.resultados_divergencia_regiones, 'o')
-            plt.plot(range(1, len(self.resultados_divergencia_regiones)+1),
-                     self.resultados_divergencia_regiones)
-            plt.show()
-
     def regresa_imagen_grafica(self, grafica):
         print("-----------------------------------------------")
         print("Gráfica deseada:", grafica)
